@@ -1,6 +1,5 @@
 /*
  *  xfce4-mailwatch-plugin - a mail notification applet for the xfce4 panel
- *  Copyright (c) 2013 Ján Sučan <sucan@runbox.com>
  *  Copyright (c) 2005-2008 Brian Tarricone <bjt23@cornell.edu>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -65,10 +64,6 @@
 #include "mailwatch-utils.h"
 #include "mailwatch.h"
 
-#ifndef GTK_STOCK_DIRECTORY
-#define GTK_STOCK_DIRECTORY      GTK_STOCK_OPEN
-#endif
-
 #define BORDER                   8
 
 #define XFCE_MAILWATCH_IMAP_MAILBOX(ptr) ((XfceMailwatchIMAPMailbox *)ptr)
@@ -81,7 +76,7 @@ typedef struct
     XfceMailwatchMailbox mailbox;
     XfceMailwatch *mailwatch;
     
-    GMutex *config_mx;
+    GMutex config_mx;
     
     guint timeout;
     gchar *host;
@@ -294,7 +289,7 @@ imap_send_login_info(XfceMailwatchIMAPMailbox *imailbox,
         g_snprintf(buf, BUFSIZE, "%05d AUTHENTICATE CRAM-MD5\r\n",
                    ++imailbox->imap_tag);
         bout = imap_send(imailbox, net_conn, buf);
-        if(bout != strlen(buf))
+        if(bout != (gint)strlen(buf))
             goto cleanuperr;
         
         bin = imap_recv(imailbox, net_conn, buf, BUFSIZE);
@@ -321,7 +316,7 @@ imap_send_login_info(XfceMailwatchIMAPMailbox *imailbox,
             g_free(response_base64);
             bout = imap_send(imailbox, net_conn, buf);
             DBG("sent CRAM-MD5 response: %s\n", buf);
-            if(bout != strlen(buf))
+            if(bout != (gint)strlen(buf))
                 goto cleanuperr;
 
             bin = imap_recv_command(imailbox, net_conn, buf, BUFSIZE);
@@ -648,10 +643,10 @@ imap_check_mail_th(gpointer user_data)
         return NULL;
     }
 
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     if(!imailbox->host || !imailbox->username || !imailbox->password) {
-        g_mutex_unlock(imailbox->config_mx);
+        g_mutex_unlock(&(imailbox->config_mx));
         g_atomic_pointer_set(&imailbox->th, NULL);
         return NULL;
     }
@@ -667,7 +662,7 @@ imap_check_mail_th(gpointer user_data)
     for(l = imailbox->mailboxes_to_check; l; l = l->next)
         mailboxes_to_check = g_list_prepend(mailboxes_to_check, g_strdup(l->data));
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     /* escape stuff */
     imap_escape_string(username, BUFSIZE);
@@ -693,8 +688,7 @@ imap_check_mail_th(gpointer user_data)
         imap_send(imailbox, net_conn, "ABCD LOGOUT\r\n");
     
     if(mailboxes_to_check) {
-        g_list_foreach(mailboxes_to_check, (GFunc)g_free, NULL);
-        g_list_free(mailboxes_to_check);
+        g_list_free_full(mailboxes_to_check, g_free);
     }
     
     xfce_mailwatch_net_conn_destroy(net_conn);
@@ -712,7 +706,8 @@ imap_mailbox_new(XfceMailwatch *mailwatch, XfceMailwatchMailboxType *type)
     imailbox->mailwatch = mailwatch;
     imailbox->timeout = XFCE_MAILWATCH_DEFAULT_TIMEOUT;
     imailbox->use_standard_port = TRUE;
-    imailbox->config_mx = g_mutex_new();
+
+    g_mutex_init(&imailbox->config_mx);
 
     /* this is a bit of a hack; should really fetch the folder list and
      * try to find the inbox, as the inbox might not be named "INBOX" */
@@ -736,8 +731,7 @@ imap_check_mail_timeout(gpointer data)
                                    _("Previous thread hasn't exited yet, not checking mail this time."));
         return TRUE;
     }
-
-    th = g_thread_create(imap_check_mail_th, imailbox, FALSE, NULL);
+    th = g_thread_try_new(NULL, imap_check_mail_th, imailbox, NULL);
     g_atomic_pointer_set(&imailbox->th, th);
 
     return TRUE;
@@ -795,7 +789,7 @@ imap_host_entry_focus_out_cb(GtkWidget *w, GdkEventFocus *evt,
     
     str = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     g_free(imailbox->host);
     if(!str || !*str) {
@@ -804,7 +798,7 @@ imap_host_entry_focus_out_cb(GtkWidget *w, GdkEventFocus *evt,
     } else
         imailbox->host = str;
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     return FALSE;
 }
@@ -818,7 +812,7 @@ imap_username_entry_focus_out_cb(GtkWidget *w, GdkEventFocus *evt,
     
     str = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     g_free(imailbox->username);
     if(!str || !*str) {
@@ -827,7 +821,7 @@ imap_username_entry_focus_out_cb(GtkWidget *w, GdkEventFocus *evt,
     } else
         imailbox->username = str;
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     return FALSE;
 }
@@ -841,7 +835,7 @@ imap_password_entry_focus_out_cb(GtkWidget *w, GdkEventFocus *evt,
     
     str = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     g_free(imailbox->password);
     if(!str || !*str) {
@@ -850,7 +844,7 @@ imap_password_entry_focus_out_cb(GtkWidget *w, GdkEventFocus *evt,
     } else
         imailbox->password = str;
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     return FALSE;
 }
@@ -1099,7 +1093,7 @@ imap_populate_folder_tree_nodes(gpointer user_data)
     if(!imailbox->folder_tree_dialog)
         return FALSE;
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     /* make a deep copy of the mailbox list */
     mailboxes_to_check = g_hash_table_new_full(g_str_hash, g_str_equal,
@@ -1107,7 +1101,7 @@ imap_populate_folder_tree_nodes(gpointer user_data)
     for(l = imailbox->mailboxes_to_check; l; l = l->next)
         g_hash_table_insert(mailboxes_to_check, g_strdup(l->data), GINT_TO_POINTER(1));
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     gtk_tree_store_clear(imailbox->ts);
     g_object_set(G_OBJECT(imailbox->render), "foreground-set", FALSE,
@@ -1206,10 +1200,10 @@ imap_populate_folder_tree_th(gpointer data)
         return NULL;
     }
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     if(!imailbox->host || !imailbox->username || !imailbox->password) {
-        g_mutex_unlock(imailbox->config_mx);
+        g_mutex_unlock(&(imailbox->config_mx));
         g_idle_add(imap_folder_tree_th_join, imailbox);
         g_atomic_pointer_set(&imailbox->folder_tree_th, NULL);
         return NULL;
@@ -1222,7 +1216,7 @@ imap_populate_folder_tree_th(gpointer data)
     if(!imailbox->use_standard_port)
         nonstandard_port = imailbox->nonstandard_port;
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     imap_escape_string(username, BUFSIZE);
     imap_escape_string(password, BUFSIZE);
@@ -1293,8 +1287,7 @@ imap_config_refresh_btn_clicked_cb(GtkWidget *w, gpointer user_data)
                 "style-set", TRUE, NULL);
 
     g_atomic_int_set(&imailbox->folder_tree_running, TRUE);
-    th = g_thread_create(imap_populate_folder_tree_th,
-                         imailbox, FALSE, NULL);
+    th = g_thread_try_new(NULL, imap_populate_folder_tree_th, imailbox, NULL);
     g_atomic_pointer_set(&imailbox->folder_tree_th, th);
 }
 
@@ -1326,7 +1319,7 @@ imap_config_treeview_btnpress_cb(GtkWidget *w, GdkEventButton *evt,
                 gtk_tree_store_set(imailbox->ts, &itr,
                         IMAP_FOLDERS_WATCHING, !watching, -1);
                 
-                g_mutex_lock(imailbox->config_mx);
+                g_mutex_lock(&(imailbox->config_mx));
                 if(watching) {
                     GList *l;
                     for(l = imailbox->mailboxes_to_check; l; l = l->next) {
@@ -1345,7 +1338,7 @@ imap_config_treeview_btnpress_cb(GtkWidget *w, GdkEventButton *evt,
                                     folder_path);
                     DBG("IMAP: adding %s to the new mail folder list (not saved yet)", folder_path);
                 }
-                g_mutex_unlock(imailbox->config_mx);
+                g_mutex_unlock(&(imailbox->config_mx));
             } else
                 g_free(folder_path);
             
@@ -1394,32 +1387,36 @@ imap_config_newmailfolders_btn_clicked_cb(GtkWidget *w, gpointer user_data)
         g_thread_yield();
     
     if(!imailbox->host || !imailbox->username) {
-        xfce_message_dialog(toplevel, _("Error"), GTK_STOCK_DIALOG_WARNING,
+        xfce_message_dialog(toplevel, _("Error"), "dialog-warning",
                             _("No server or username is set."),
-                            _("The folder list cannot be retrieved until a server, username, and probably password are set.  Also be sure to check any security settings in the Advanced dialog."),
-                            GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT, NULL);
+                            _("The folder list cannot be retrieved until a "
+                            "server, username, and probably password are set. "
+                            " Also be sure to check any security settings in "
+                            "the Advanced dialog."),
+                            _("_Close"), GTK_RESPONSE_ACCEPT,
+                            NULL);
         return;
     }
     
     dlg = gtk_dialog_new_with_buttons(_("Set New Mail Folders"), toplevel,
-                                      GTK_DIALOG_DESTROY_WITH_PARENT
-                                      | GTK_DIALOG_NO_SEPARATOR,
-                                      GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
+                                      GTK_DIALOG_DESTROY_WITH_PARENT,
+                                      _("_Close"), GTK_RESPONSE_ACCEPT,
                                       NULL);
     imailbox->folder_tree_dialog = dlg;
-    topvbox = gtk_vbox_new(FALSE, BORDER/2);
+    topvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER/2);
     gtk_container_set_border_width(GTK_CONTAINER(topvbox), BORDER/2);
     gtk_widget_show(topvbox);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), topvbox, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg))),
+                       topvbox, TRUE, TRUE, 0);
     g_signal_connect(G_OBJECT(dlg), "destroy",
                      G_CALLBACK(imap_config_newmailfolders_destroy_cb),
                      imailbox);
     
-    frame = xfce_mailwatch_create_framebox(_("New Mail Folders"), &frame_bin);
+    frame = xfce_gtk_frame_box_new(_("New Mail Folders"), &frame_bin);
     gtk_widget_show(frame);
     gtk_box_pack_start(GTK_BOX(topvbox), frame, TRUE, TRUE, 0);
     
-    hbox = gtk_hbox_new(FALSE, BORDER/2);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER/2);
     gtk_widget_show(hbox);
     gtk_container_add(GTK_CONTAINER(frame_bin), hbox);
     
@@ -1438,7 +1435,15 @@ imap_config_newmailfolders_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(ts));
     gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(treeview), FALSE);
     gtk_widget_add_events(treeview, GDK_BUTTON_PRESS);
-    
+
+    /* Add watching column */
+    render = gtk_cell_renderer_toggle_new();
+    col = gtk_tree_view_column_new_with_attributes("watching", render,
+                                                   "active", IMAP_FOLDERS_WATCHING,
+                                                   NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
+
+    /* Add name column */
     col = gtk_tree_view_column_new();
     gtk_tree_view_column_set_title(col, "mailbox-name");
     gtk_tree_view_column_set_expand(col, TRUE);
@@ -1446,7 +1451,7 @@ imap_config_newmailfolders_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     render = gtk_cell_renderer_pixbuf_new();
     gtk_tree_view_column_pack_start(col, render, FALSE);
     g_object_set(G_OBJECT(render),
-                 "stock-id", GTK_STOCK_DIRECTORY,
+                 "icon-name", "folder",
                  "stock-size", GTK_ICON_SIZE_MENU,
                  NULL);
 
@@ -1456,11 +1461,14 @@ imap_config_newmailfolders_btn_clicked_cb(GtkWidget *w, gpointer user_data)
                                         "text", IMAP_FOLDERS_NAME,
                                         NULL);
     {
-        GtkStyle *style;
+        GtkStyleContext *stylecontext;
+        GdkRGBA fgcolor;
+
         gtk_widget_realize(topvbox);
-        style = gtk_widget_get_style(topvbox);
-        g_object_set(G_OBJECT(render), "foreground-gdk",
-                     &style->fg[GTK_STATE_INSENSITIVE],
+        stylecontext = gtk_widget_get_style_context(GTK_WIDGET(topvbox));
+        gtk_style_context_get_color(stylecontext, GTK_STATE_FLAG_INSENSITIVE, &fgcolor);
+        g_object_set(G_OBJECT(render), "foreground-rgba",
+                     &fgcolor,
                      "foreground-set", TRUE,
                      "style", PANGO_STYLE_ITALIC,
                      "style-set", TRUE,
@@ -1469,13 +1477,7 @@ imap_config_newmailfolders_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     
     gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
     gtk_tree_view_set_expander_column(GTK_TREE_VIEW(treeview), col);
-    
-    render = gtk_cell_renderer_toggle_new();
-    col = gtk_tree_view_column_new_with_attributes("watching", render,
-                                                   "active", IMAP_FOLDERS_WATCHING,
-                                                   NULL);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
-    
+
     gtk_widget_show(treeview);
     gtk_container_add(GTK_CONTAINER(sw), treeview);
     g_signal_connect(G_OBJECT(treeview), "button-press-event",
@@ -1485,11 +1487,14 @@ imap_config_newmailfolders_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     gtk_tree_selection_set_mode(sel, GTK_SELECTION_MULTIPLE);
     gtk_tree_selection_unselect_all(sel);
     
-    vbox = gtk_vbox_new(FALSE, BORDER/2);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER/2);
     gtk_widget_show(vbox);
     gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
     
-    imailbox->refresh_btn = btn = gtk_button_new_from_stock(GTK_STOCK_REFRESH);
+    imailbox->refresh_btn = btn = gtk_button_new_with_mnemonic(_("_Refresh"));
+    gtk_button_set_image(GTK_BUTTON(btn),
+                         gtk_image_new_from_icon_name("view-refresh",
+                                                      GTK_ICON_SIZE_BUTTON));
     gtk_widget_show(btn);
     gtk_box_pack_start(GTK_BOX(vbox), btn, FALSE, FALSE, 0);
     g_object_set_data(G_OBJECT(btn), "mailwatch-treeview", treeview);
@@ -1501,8 +1506,7 @@ imap_config_newmailfolders_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     gtk_widget_set_sensitive(btn, FALSE);
 
     g_atomic_int_set(&imailbox->folder_tree_running, TRUE);
-    th = g_thread_create(imap_populate_folder_tree_th,
-                         imailbox, FALSE, NULL);
+    th = g_thread_try_new(NULL, imap_populate_folder_tree_th, imailbox, NULL);
     g_atomic_pointer_set(&imailbox->folder_tree_th, th);
     
     gtk_dialog_run(GTK_DIALOG(dlg));
@@ -1515,12 +1519,12 @@ imap_config_nonstandard_chk_cb(GtkToggleButton *tb, gpointer user_data)
     XfceMailwatchIMAPMailbox *imailbox = user_data;
     GtkWidget *entry = g_object_get_data(G_OBJECT(tb), "xfmw-entry");
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     imailbox->use_standard_port = !gtk_toggle_button_get_active(tb);
     gtk_widget_set_sensitive(entry, !imailbox->use_standard_port);
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
 }
 
 static gboolean
@@ -1529,11 +1533,11 @@ imap_config_nonstandard_focusout_cb(GtkWidget *w, GdkEventFocus *evt,
 {
     XfceMailwatchIMAPMailbox *imailbox = user_data;
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     imailbox->nonstandard_port = atoi(gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1));
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     return FALSE;
 }
@@ -1544,7 +1548,7 @@ imap_config_security_combo_changed_cb(GtkWidget *w, gpointer user_data)
     XfceMailwatchIMAPMailbox *imailbox = user_data;
     GtkWidget *entry = g_object_get_data(G_OBJECT(w), "xfmw-entry");
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     imailbox->auth_type = gtk_combo_box_get_active(GTK_COMBO_BOX(w));
     
@@ -1555,7 +1559,7 @@ imap_config_security_combo_changed_cb(GtkWidget *w, gpointer user_data)
             gtk_entry_set_text(GTK_ENTRY(entry), IMAP_PORT_S);
     }
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
 }
 
 static gboolean
@@ -1564,12 +1568,12 @@ imap_config_serverdir_focusout_cb(GtkWidget *w, GdkEventFocus *evt,
 {
     XfceMailwatchIMAPMailbox *imailbox = user_data;
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     g_free(imailbox->server_directory);
     imailbox->server_directory = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     return FALSE;
 }
@@ -1583,27 +1587,29 @@ imap_config_advanced_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     
     dlg = gtk_dialog_new_with_buttons(_("Advanced IMAP Options"),
             GTK_WINDOW(gtk_widget_get_toplevel(w)),
-            GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_NO_SEPARATOR,
-            GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT, NULL);
+            GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        _("_Close"), GTK_RESPONSE_ACCEPT,
+                                        NULL);
     gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_ACCEPT);
     
-    topvbox = gtk_vbox_new(FALSE, BORDER/2);
+    topvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER/2);
     gtk_container_set_border_width(GTK_CONTAINER(topvbox), BORDER/2);
     gtk_widget_show(topvbox);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), topvbox, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg))),
+                       topvbox, TRUE, TRUE, 0);
     
-    frame = xfce_mailwatch_create_framebox(_("Connection"), &frame_bin);
+    frame = xfce_gtk_frame_box_new(_("Connection"), &frame_bin);
     gtk_widget_show(frame);
     gtk_box_pack_start(GTK_BOX(topvbox), frame, FALSE, FALSE, 0);
     
-    vbox = gtk_vbox_new(FALSE, BORDER/2);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER/2);
     gtk_widget_show(vbox);
     gtk_container_add(GTK_CONTAINER(frame_bin), vbox);
     
-    combo = gtk_combo_box_new_text();
-    gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Use unsecured connection"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Use SSL/TLS on alternate port"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Use SSL/TLS via STARTTLS"));
+    combo = gtk_combo_box_text_new();
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Use unsecured connection"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Use SSL/TLS on alternate port"));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Use SSL/TLS via STARTTLS"));
 #ifdef HAVE_SSL_SUPPORT
     gtk_combo_box_set_active(GTK_COMBO_BOX(combo), imailbox->auth_type);
 #else
@@ -1615,7 +1621,7 @@ imap_config_advanced_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     g_signal_connect(G_OBJECT(combo), "changed",
             G_CALLBACK(imap_config_security_combo_changed_cb), imailbox);
     
-    hbox = gtk_hbox_new(FALSE, BORDER/2);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER/2);
     gtk_widget_show(hbox);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
     
@@ -1649,11 +1655,11 @@ imap_config_advanced_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     g_object_set_data(G_OBJECT(chk), "xfmw-entry", entry);
     g_object_set_data(G_OBJECT(combo), "xfmw-entry", entry);
     
-    frame = xfce_mailwatch_create_framebox(_("Folders"), &frame_bin);
+    frame = xfce_gtk_frame_box_new(_("Folders"), &frame_bin);
     gtk_widget_show(frame);
     gtk_box_pack_start(GTK_BOX(topvbox), frame, FALSE, FALSE, 0);
     
-    hbox = gtk_hbox_new(FALSE, BORDER/2);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER/2);
     gtk_widget_show(hbox);
     gtk_container_add(GTK_CONTAINER(frame_bin), hbox);
     
@@ -1663,10 +1669,10 @@ imap_config_advanced_btn_clicked_cb(GtkWidget *w, gpointer user_data)
     
     entry = gtk_entry_new();
     gtk_entry_set_activates_default(GTK_ENTRY(entry), TRUE);
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     if(imailbox->server_directory)
         gtk_entry_set_text(GTK_ENTRY(entry), imailbox->server_directory);
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     gtk_widget_show(entry);
     gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
     g_signal_connect(G_OBJECT(entry), "focus-out-event",
@@ -1684,25 +1690,25 @@ imap_get_setup_page(XfceMailwatchMailbox *mailbox)
               *sbtn;
     GtkSizeGroup *sg;
     
-    topvbox = gtk_vbox_new(FALSE, BORDER/2);
+    topvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER/2);
     gtk_widget_show(topvbox);
     
-    frame = xfce_mailwatch_create_framebox(_("IMAP Server"), &frame_bin);
+    frame = xfce_gtk_frame_box_new(_("IMAP Server"), &frame_bin);
     gtk_widget_show(frame);
     gtk_box_pack_start(GTK_BOX(topvbox), frame, FALSE, FALSE, 0);
     
     sg = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
     
-    vbox = gtk_vbox_new(FALSE, BORDER/2);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER/2);
     gtk_widget_show(vbox);
     gtk_container_add(GTK_CONTAINER(frame_bin), vbox);
     
-    hbox = gtk_hbox_new(FALSE, BORDER/2);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER/2);
     gtk_widget_show(hbox);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
     
     lbl = gtk_label_new_with_mnemonic(_("_Mail server:"));
-    gtk_misc_set_alignment(GTK_MISC(lbl), 0.0, 0.5);
+    gtk_label_set_xalign(GTK_LABEL(lbl), 0.0);
     gtk_widget_show(lbl);
     gtk_box_pack_start(GTK_BOX(hbox), lbl, FALSE, FALSE, 0);
     gtk_size_group_add_widget(sg, lbl);
@@ -1717,12 +1723,12 @@ imap_get_setup_page(XfceMailwatchMailbox *mailbox)
             G_CALLBACK(imap_host_entry_focus_out_cb), imailbox);
     gtk_label_set_mnemonic_widget(GTK_LABEL(lbl), entry);
     
-    hbox = gtk_hbox_new(FALSE, BORDER/2);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER/2);
     gtk_widget_show(hbox);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
     
     lbl = gtk_label_new_with_mnemonic(_("_Username:"));
-    gtk_misc_set_alignment(GTK_MISC(lbl), 0.0, 0.5);
+    gtk_label_set_xalign(GTK_LABEL(lbl), 0.0);
     gtk_widget_show(lbl);
     gtk_box_pack_start(GTK_BOX(hbox), lbl, FALSE, FALSE, 0);
     gtk_size_group_add_widget(sg, lbl);
@@ -1737,12 +1743,12 @@ imap_get_setup_page(XfceMailwatchMailbox *mailbox)
             G_CALLBACK(imap_username_entry_focus_out_cb), imailbox);
     gtk_label_set_mnemonic_widget(GTK_LABEL(lbl), entry);
     
-    hbox = gtk_hbox_new(FALSE, BORDER/2);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER/2);
     gtk_widget_show(hbox);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
     
     lbl = gtk_label_new_with_mnemonic(_("_Password:"));
-    gtk_misc_set_alignment(GTK_MISC(lbl), 0.0, 0.5);
+    gtk_label_set_xalign(GTK_LABEL(lbl), 0.0);
     gtk_widget_show(lbl);
     gtk_box_pack_start(GTK_BOX(hbox), lbl, FALSE, FALSE, 0);
     gtk_size_group_add_widget(sg, lbl);
@@ -1758,25 +1764,29 @@ imap_get_setup_page(XfceMailwatchMailbox *mailbox)
             G_CALLBACK(imap_password_entry_focus_out_cb), imailbox);
     gtk_label_set_mnemonic_widget(GTK_LABEL(lbl), entry);
     
-    hbox = gtk_hbox_new(FALSE, BORDER/2);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER/2);
     gtk_widget_show(hbox);
     gtk_box_pack_start(GTK_BOX(topvbox), hbox, FALSE, FALSE, 0);
     
-    btn = xfce_mailwatch_custom_button_new(_("_Advanced..."),
-            GTK_STOCK_PREFERENCES);
+    btn = gtk_button_new_with_mnemonic(_("_Advanced..."));
+    gtk_button_set_image(GTK_BUTTON(btn),
+                         gtk_image_new_from_icon_name("preferences-other",
+                                                      GTK_ICON_SIZE_BUTTON));
     gtk_widget_show(btn);
     gtk_box_pack_start(GTK_BOX(hbox), btn, FALSE, FALSE, 0);
     g_signal_connect(G_OBJECT(btn), "clicked",
             G_CALLBACK(imap_config_advanced_btn_clicked_cb), imailbox);
     
-    btn = xfce_mailwatch_custom_button_new(_("New mail _folders..."),
-            GTK_STOCK_DIRECTORY);
+    btn = gtk_button_new_with_mnemonic(_("New mail _folders..."));
+    gtk_button_set_image(GTK_BUTTON(btn),
+                         gtk_image_new_from_icon_name("folder",
+                                                      GTK_ICON_SIZE_BUTTON));
     gtk_widget_show(btn);
     gtk_box_pack_start(GTK_BOX(hbox), btn, FALSE, FALSE, 0);
     g_signal_connect(G_OBJECT(btn), "clicked",
             G_CALLBACK(imap_config_newmailfolders_btn_clicked_cb), imailbox);
     
-    hbox = gtk_hbox_new(FALSE, BORDER/2);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER/2);
     gtk_widget_show(hbox);
     gtk_box_pack_start(GTK_BOX(topvbox), hbox, FALSE, FALSE, 0);
     
@@ -1808,7 +1818,7 @@ imap_restore_param_list(XfceMailwatchMailbox *mailbox, GList *params)
     GList *l;
     gint n_newmail_boxes = 0;
     
-    g_mutex_lock(imailbox->config_mx);
+    g_mutex_lock(&(imailbox->config_mx));
     
     for(l = params; l; l = l->next) {
         XfceMailwatchParam *param = l->data;
@@ -1859,7 +1869,7 @@ imap_restore_param_list(XfceMailwatchMailbox *mailbox, GList *params)
             imailbox->mailboxes_to_check = inbox_l;
     }
 
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
 }
 
 static GList *
@@ -1870,8 +1880,7 @@ imap_save_param_list(XfceMailwatchMailbox *mailbox)
     XfceMailwatchParam *param;
     guint i;
     
-    g_mutex_lock(imailbox->config_mx);
-    
+    g_mutex_lock(&(imailbox->config_mx));
     param = g_new(XfceMailwatchParam, 1);
     param->key = g_strdup("host");
     param->value = g_strdup(imailbox->host);
@@ -1928,7 +1937,7 @@ imap_save_param_list(XfceMailwatchMailbox *mailbox)
             param->value);
     }
     
-    g_mutex_unlock(imailbox->config_mx);
+    g_mutex_unlock(&(imailbox->config_mx));
     
     return g_list_reverse(params);
 }
@@ -1947,7 +1956,7 @@ imap_mailbox_free(XfceMailwatchMailbox *mailbox)
     while(g_atomic_pointer_get(&imailbox->th))
         g_thread_yield();
     
-    g_mutex_free(imailbox->config_mx);
+    g_mutex_clear(&imailbox->config_mx);
     
     g_free(imailbox->host);
     g_free(imailbox->username);
