@@ -19,7 +19,7 @@
 #ifndef __MAILWATCH_UTILS_H__
 #define __MAILWATCH_UTILS_H__
 
-#include <gtk/gtk.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
@@ -30,22 +30,10 @@ typedef enum
     AUTH_STARTTLS
 } XfceMailwatchAuthType;
 
-GtkWidget *xfce_mailwatch_custom_button_new(const gchar *text,
-                                            const gchar *icon);
-GtkWidget *xfce_mailwatch_create_framebox(const gchar *title,
-                                          GtkWidget **frame_bin);
-
 gchar *xfce_mailwatch_cram_md5(const gchar *username,
                                const gchar *password,
                                const gchar *challenge_base64);
 
-gint xfce_mailwatch_base64_encode(const guint8 *data,
-                                  gsize size,
-                                  gchar **str);
-gint xfce_mailwatch_base64_decode(const gchar *str,
-                                  guint8 *data,
-                                  gsize size);
-
 G_END_DECLS
 
 #endif
